##  Overview
In SAP LeanIX, you will find three different types of relations between fact sheets:
  1. Explicit Relations: Specific, named relationships between two different fact sheet types.
  2. Parent / Child: Hierarchical structures within the same fact sheet type.
  3. Requires / Required By: Logical or technical dependencies between different fact sheets.
  4. Transitive: An indirect connection between two fact sheets that is inferred through a chain of existing relationships.
